use crate::config;
use sqlx_postgres::{PgPool, PgPoolOptions};
use std::sync::OnceLock;
use std::time::Duration;

static DB: OnceLock<PgPool> = OnceLock::new();

/// 初始化数据库连接池
pub async fn init_database() {
    let config = config!();
    let db_cfg = &config.database;

    let pool = PgPoolOptions::new()
        .min_connections(db_cfg.options.min_conns)
        .max_connections(db_cfg.options.max_conns)
        .acquire_timeout(Duration::from_secs(db_cfg.options.conn_timeout))
        .idle_timeout(Duration::from_secs(db_cfg.options.idle_timeout))
        .max_lifetime(Duration::from_secs(db_cfg.options.max_lifetime))
        .connect(&db_cfg.url)
        .await
        .unwrap_or_else(|e| panic!("数据库连接失败：{}", e));

    pool.acquire()
        .await
        .unwrap_or_else(|e| panic!("数据库连接失败：{}", e));

    let _ = DB.set(pool);
}

pub fn conn() -> &'static PgPool {
    DB.get().unwrap_or_else(|| panic!("数据库连接未初始化"))
}

#[macro_export]
macro_rules! db {
    () => {
        library::core::db::conn()
    };
}
